DataSource class

Constructors

DataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cp ↔ CommonResponse
getter/setter pair
getAllCouponsAPI ↔ String
getter/setter pair
instance ↔ DataSource
getter/setter pair
redeemAPI ↔ String
getter/setter pair
verifyAPI ↔ String
getter/setter pair

Static Methods

getAllCoupons(String key, {required void successCompletion(CommonResponse), required void errCompletion(CommonResponse)}) → Future<CommonResponse>
redeemCoupon(Map<String, dynamic> options, {required void successCompletion(CommonResponse), required void errCompletion(CommonResponse)}) → Future<CommonResponse>
verifyCoupon(Map<String, dynamic> options, {required void successCompletion(CommonResponse), required void errCompletion(CommonResponse)}) → Future<CommonResponse>